General Configuration
=====================

Managing LinchPin requires a few configuration files. Beyond :term:`linchpin.conf`, there are a few other configurations that need to be created.

.. contents:: Topics

Workspace
`````````

.. include:: includes/workspace.rst

Initialization
``````````````

.. include:: includes/initialization.rst

PinFile
```````

.. include:: includes/pinfile.rst

Topologies
``````````

.. include:: includes/topologies.rst

Inventory Layouts
`````````````````

.. include:: includes/layouts.rst

